EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_CreateOrUpdateVulnerabilityAnalysis',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ 'VulnerabilitiesAnalysis',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates an analysis for a vulnerability.'
GO

IF OBJECT_ID('[Vulnerabilities_CreateOrUpdateVulnerabilityAnalysis]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_CreateOrUpdateVulnerabilityAnalysis]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [Vulnerabilities_CreateOrUpdateVulnerabilityAnalysis]
(
    @UniqueId_Text VARCHAR(20),
    @Author_Text VARCHAR(100),
    @Analysis_Text VARCHAR(MAX)
)
AS
BEGIN
    SET NOCOUNT ON

	DECLARE @Vulnerability_Id INT = (SELECT [Vulnerability_Id] FROM [Vulnerabilities] WHERE [UniqueId_Text] = @UniqueId_Text)

    IF EXISTS (SELECT * FROM [VulnerabilityAnalysis] WHERE [Vulnerability_Id] = @Vulnerability_Id)
    BEGIN
        UPDATE [VulnerabilityAnalysis]
        SET [Author_Text] = @Author_Text,
            [Analysis_Text] = @Analysis_Text,
            [AssessedOn_Date] = GETUTCDATE()
        WHERE [Vulnerability_Id] = @Vulnerability_Id
    END
    ELSE BEGIN
        INSERT INTO [VulnerabilityAnalysis]
        (
            [Vulnerability_Id],
            [Author_Text],
            [Analysis_Text],
            [AssessedOn_Date]
        )
        VALUES
        (
            @Vulnerability_Id,
            @Author_Text,
            @Analysis_Text,
            GETUTCDATE()
        )
    END

END
GO

GRANT EXECUTE ON [Vulnerabilities_CreateOrUpdateVulnerabilityAnalysis] TO [InedoSecurityLabsUser_Role]
GO